BibleAPI class

A provider for the ESV bible translation. Requires an API key.

Activate an API key here.

Inheritance

Constructors

BibleAPI()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
requiresKey → bool
Whether this provider requires an API key to work.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versions → List<String>
no setterinherited

Methods

containsVersion(String version) → bool
Whether or not this provider can query certain a versions.
inherited
getPassage(BibleReference query, {Map<String, String>? parameters, String? key, String? version}) → Future<PassageQuery>
Queries the bibleapi.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited