BibleProvider class abstract

A source for bible content

Implementers

Constructors

BibleProvider(String name, bool _requiresKey, Set<String> _versions)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
requiresKey → bool
Whether this provider requires an API key to work.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versions → List<String>
no setter

Methods

containsVersion(String version) → bool
Whether or not this provider can query certain a versions.
getPassage(BibleReference query, {Map<String, String>? parameters, String? key, String? version}) → Future<PassageQuery>
Fetch a passage from this provider's designated provider source.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited